﻿using ModuleTools.Attributes;
using ModuleTools.Enums;
using ModuleTools.ViewModels;
using System;
using System.Text;

namespace DepartmentBusinessLogic.ViewModels
{
	/// <summary>
	/// Список учебных групп
	/// </summary>
	public class StudentGroupListViewModel : ListViewModel<StudentGroupViewModel> { }

	/// <summary>
	/// Элемент учебная группа
	/// </summary>
	[ViewModelControlElementClass(HaveDependenceEntities = true, Width = 800, Height = 500)]
	[ViewModelControlElementDependenceEntity(Title = "Студенты", Order = 1, ParentPropertyName = "StudentGroupId",
		ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlStudentList, DepartmentWindowsDesktop")]
	[ViewModelControlElementDependenceEntity(Title = "Приказы", Order = 1, ParentPropertyName = "StudentGroupId",
		ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlOrderStudentRecordList, DepartmentWindowsDesktop")]
	public class StudentGroupViewModel : ElementViewModel
	{
		[ViewModelControlElementProperty("Учебный план", ControlType.ControlGuid, MustHaveValue = true, ReadOnly = false, ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlAcademicPlanList, DepartmentWindowsDesktop")]
		[MapConfiguration("AcademicPlanId")]
		public Guid AcademicPlanId { get; set; }

		[ViewModelControlListProperty("Шифр", ColumnWidth = 80)]
		[MapConfiguration("AcademicPlan.EducationDirection.Cipher", IsDifficle = true)]
		public string AcademicPlanEducationDirectionCipher { get; set; }

		[ViewModelControlListProperty("Профиль")]
		[MapConfiguration("AcademicPlan.EducationDirection.Profile", IsDifficle = true)]
		public string AcademicPlanEducationDirectionProfile { get; set; }

		[MapConfiguration("AcademicPlan.EducationDirection.ShortName", IsDifficle = true)]
		public string AcademicPlanEducationDirectionShortName { get; set; }

		[ViewModelControlListProperty("Группа")]
		public string GroupName
		{
			get
			{
				var builder = new StringBuilder();
				builder.Append(AcademicPlanEducationDirectionShortName);
				builder.Append('-');
				var year = DateTime.Now.Year - EnrollmentYear;
				if (DateTime.Now.Month > 8)
				{
					year++;
				}
				builder.Append(year);
				builder.Append(GroupNumber);

				return builder.ToString();
			}
		}

		[ViewModelControlListProperty("Номер группы")]
		[ViewModelControlElementProperty("Номер группы", ControlType.ControlInt, MustHaveValue = true, MinValue = 1, MaxValue = 4)]
		[MapConfiguration("GroupNumber")]
		public int GroupNumber { get; set; }

		[ViewModelControlListProperty("Год зачисления")]
		[ViewModelControlElementProperty("Год зачисления", ControlType.ControlInt, MustHaveValue = true)]
		[MapConfiguration("EnrollmentYear")]
		public int EnrollmentYear { get; set; }

		[ViewModelControlElementProperty("Куратор", ControlType.ControlGuid, MustHaveValue = false, ReadOnly = false, ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlLecturerList, DepartmentWindowsDesktop")]
		[MapConfiguration("LecturerId")]
		public Guid? LecturerId { get; set; }

		[ViewModelControlListProperty("Куратор")]
		[MapConfiguration("Lecturer.ToString", IsDifficle = true)]
		public string Lecturer { get; set; }
	}
}